@@ -115,7 +115,7 @@ class Orden(BaseModel):
 
         elements = self.dict(
             exclude_none=True,
-            exclude={'id', 'categoria', 'op_ins_clave_ben'},
+            exclude={'id', 'categoria', 'op_ins_clave_ord'},
         )
 
         for element, value in elements.items():  # noqa: WPS110
@@ -124,7 +124,7 @@ class Orden(BaseModel):
                     subelement = etree.SubElement(ordenpago, 'opFirmaDig')
                     subelement.text = str(value)
                     continue
-                if element == 'op_ins_clave_ord':
+                if element == 'op_ins_clave_ben':
                     subelement = etree.SubElement(ordenpago, 'OpInsClave')
                     subelement.text = str(value)
                     continue
